# -*- coding: utf-8 -*-
"""
Created on Fri Aug 14 14:41:53 2020

@author: supakrni
"""

from pyrmvtxt.rmvtxt_code import removetxt
